<?php

namespace Teste\Teste\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Teste\Teste\Interfaces\Tabela1RepositoryInterface;
use Teste\Teste\Repositories\Presenter\Tabela1ItemTransformer;

/**
 * Pubic API controller class.
 */
class Tabela1PublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Teste\Tabela1\Interfaces\Tabela1RepositoryInterface $tabela1
     *
     * @return type
     */
    public function __construct(Tabela1RepositoryInterface $tabela1)
    {
        $this->repository = $tabela1;
        parent::__construct();
    }

    /**
     * Show tabela1's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $tabela1s = $this->repository
            ->setPresenter('\\Teste\\Teste\\Repositories\\Presenter\\Tabela1ListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $tabela1s['code'] = 2000;
        return response()->json($tabela1s)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show tabela1.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $tabela1 = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($tabela1)) {
            $tabela1         = $this->itemPresenter($module, new Tabela1ItemTransformer);
            $tabela1['code'] = 2001;
            return response()->json($tabela1)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
