<?php

namespace Teste\Teste\Policies;

use App\User;
use Teste\Teste\Models\Tabela1;

class Tabela1Policy
{

    /**
     * Determine if the given user can view the tabela1.
     *
     * @param User $user
     * @param Tabela1 $tabela1
     *
     * @return bool
     */
    public function view(User $user, Tabela1 $tabela1)
    {
        if ($user->canDo('teste.tabela1.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $tabela1->user_id;
    }

    /**
     * Determine if the given user can create a tabela1.
     *
     * @param User $user
     * @param Tabela1 $tabela1
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('teste.tabela1.create');
    }

    /**
     * Determine if the given user can update the given tabela1.
     *
     * @param User $user
     * @param Tabela1 $tabela1
     *
     * @return bool
     */
    public function update(User $user, Tabela1 $tabela1)
    {
        if ($user->canDo('teste.tabela1.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $tabela1->user_id;
    }

    /**
     * Determine if the given user can delete the given tabela1.
     *
     * @param User $user
     * @param Tabela1 $tabela1
     *
     * @return bool
     */
    public function destroy(User $user, Tabela1 $tabela1)
    {
        if ($user->canDo('teste.tabela1.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $tabela1->user_id;
    }

    /**
     * Determine if the given user can verify the given tabela1.
     *
     * @param User $user
     * @param Tabela1 $tabela1
     *
     * @return bool
     */
    public function verify(User $user, Tabela1 $tabela1)
    {
        if ($user->canDo('teste.tabela1.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('teste.tabela1.verify') 
        && $user->is('manager')
        && $tabela1->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given tabela1.
     *
     * @param User $user
     * @param Tabela1 $tabela1
     *
     * @return bool
     */
    public function approve(User $user, Tabela1 $tabela1)
    {
        if ($user->canDo('teste.tabela1.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
