<?php

namespace Teste\Teste\Providers;

use Illuminate\Support\ServiceProvider;

class TesteServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'teste');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'teste');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('teste', function ($app) {
            return $this->app->make('Teste\Teste\Teste');
        });

        // Bind Tabela1 to repository
        $this->app->bind(
            \Teste\Teste\Interfaces\Tabela1RepositoryInterface::class,
            \Teste\Teste\Repositories\Eloquent\Tabela1Repository::class
        );

        $this->app->register(\Teste\Teste\Providers\AuthServiceProvider::class);
        $this->app->register(\Teste\Teste\Providers\EventServiceProvider::class);
        $this->app->register(\Teste\Teste\Providers\RouteServiceProvider::class);
        // $this->app->register(\Teste\Teste\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['teste'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('teste/teste.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/teste')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/teste')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
