<?php

namespace Teste\Teste\Workflow;

use Teste\Teste\Models\Tabela1;
use Validator;

class Tabela1Validator
{

    /**
     * Determine if the given tabela1 is valid for complete status.
     *
     * @param Tabela1 $tabela1
     *
     * @return bool / Validator
     */
    public function complete(Tabela1 $tabela1)
    {
        return Validator::make($tabela1->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given tabela1 is valid for verify status.
     *
     * @param Tabela1 $tabela1
     *
     * @return bool / Validator
     */
    public function verify(Tabela1 $tabela1)
    {
        return Validator::make($tabela1->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given tabela1 is valid for approve status.
     *
     * @param Tabela1 $tabela1
     *
     * @return bool / Validator
     */
    public function approve(Tabela1 $tabela1)
    {
        return Validator::make($tabela1->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given tabela1 is valid for publish status.
     *
     * @param Tabela1 $tabela1
     *
     * @return bool / Validator
     */
    public function publish(Tabela1 $tabela1)
    {
        return Validator::make($tabela1->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given tabela1 is valid for archive status.
     *
     * @param Tabela1 $tabela1
     *
     * @return bool / Validator
     */
    public function archive(Tabela1 $tabela1)
    {
        return Validator::make($tabela1->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given tabela1 is valid for unpublish status.
     *
     * @param Tabela1 $tabela1
     *
     * @return bool / Validator
     */
    public function unpublish(Tabela1 $tabela1)
    {
        return Validator::make($tabela1->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
